@@ -26,8 +26,10 @@
 
 int main(int argc, char* argv[])
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
 
     // Use QScopedPointer to ensure the QCoreApplication instance is deleted
     // before libraries unload, to avoid crashes during clean-up.
